==> 1.0.1.tar.gz: ios/Classes/SwiftSpectusInAppPurchasePlugin.swift <==
import Flutter
import UIKit

public class SwiftSpectusInAppPurchasePlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "spectus_in_app_purchase", binaryMessenger: registrar.messenger())
        let instance = SwiftSpectusInAppPurchasePlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if (call.method == "getPlatformVersion") {
            result("iOS " + UIDevice.current.systemVersion)
        }
        else if (call.method == "startInAppPurchaseWith") {
            //In-App Purchase Payment
            guard let args = call.arguments else {
                return
            }
            if let myArgs = args as? [String: Any], let prodId = myArgs["productID"] String {
                IAPHelper.shared.startInAppPurchaseWith(productIdentifier : prodId, { (errorMessage, transactionObj, transactionID) in
                    if errorMessage != nil {
                        result("NA")
                    } else {
                        result(transactionID)
                    }
                })
            }
        }
        else if (call.method == "startRestorePurchase") {
            //In-App Restore Purchase
            IAPHelper.shared.restorePurchase({ (errorMessage, transactionObj) in
                if errorMessage != nil {
                    result("NA")
                } else {
                    if let transactionID = transactionObj?.transactionIdentifier {
                        result(transactionID)
                    } else {
                        result("NA")
                    }
                }
            })
        }
        else {
            result("Failed to get top controller")
        }
    }
}

==> 3.0.50.tar.gz: ios/Classes/SwiftSpectusInAppPurchasePlugin.swift <==
import Flutter
import UIKit

public class SwiftSpectusInAppPurchasePlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "spectus_in_app_purchase", binaryMessenger: registrar.messenger())
        let instance = SwiftSpectusInAppPurchasePlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if (call.method == "getPlatformVersion") {
            result("iOS " + UIDevice.current.systemVersion)
        }
        else if (call.method == "startInAppPurchaseWith") {
            //In-App Purchase Payment
            guard let args = call.arguments else {
                return
            }
            if let myArgs = args as? [String: Any], let prodId = myArgs["productID"] as? String {
                IAPHelper.shared.startInAppPurchaseWith(productIdentifier : prodId, { (errorMessage, transactionObj, transactionID) in
                    if errorMessage != nil {
                        result("NA")
                    } else {
                        result(transactionID)
                    }
                })
            }
        }
        else if (call.method == "startRestorePurchase") {
            //In-App Restore Purchase
            IAPHelper.shared.restorePurchase({ (errorMessage, transactionObj) in
                if errorMessage != nil {
                    result("NA")
                } else {
                    if let transactionID = transactionObj?.transactionIdentifier {
                        result(transactionID)
                    } else {
                        result("NA")
                    }
                }
            })
        }
        else {
            result("Failed to get top controller")
        }
    }
}
